local events = {};

TallyMobTable = {};

-- COMBAT_LOG_EVENT_UNFILTERED event handler
function events:COMBAT_LOG_EVENT_UNFILTERED(timestamp, event, hideCaster, sourceGUID, sourceName, eventFlags, ...)
  if (sourceName ~= nil) then 
    -- print(sourceName .. ": Event:" .. event .. ":" .. eventFlags);
  end -- COMBAT_LOG_EVENT_UNFILTERED event handler
end

-- UPDATE_MOUSEOVER_UNIT event handler
function events:UPDATE_MOUSEOVER_UNIT(...)
  storeData("mouseover");
end -- UPDATE_MOUSEOVER_UNIT event handler

-- Function storeData(string)
--
-- Stores the data it can pull from the unitID to the database
--
function storeData(unitID)
  local mob = {}
  local name = UnitName(unitID)
  local guid = UnitGUID(unitID)
  local mobType
  local guidToStoreUnder
  
  guidToStoreUnder, mobType = ParseGUID(guid)
  
  if ((TallyMobTable[guidToStoreUnder] ~= nil) or (mobType ~= "NPC")) then return end
  mob["name"] = name;
  
  -- what is the class of the unit
  local class
  
  class = UnitClassBase(unitID)
  mob["class"] = class
  
  -- Classification of mob
  local classification
  classification = UnitClassification(unitID)
  mob["classification"] = classification
 
  -- family
  local family
  family = UnitCreatureFamily(unitID)
  mob["family"] = family
 
  local unitType
  unitType = UnitCreatureType(unitID)
  mob["type"] = unitType
 
  local health
  local maxHealth
  health = UnitHealth(unitID)
  maxHealth = UnitHealthMax(unitID)
  mob["health"] = health .. ":" .. maxHealth
 
  local powerType
  local powerName
  local power
  local maxPower
  powerType, powerName = UnitPowerType(unitID)
  power = UnitPower(unitID)
  maxPower = UnitPowerMax(unitID)
  mob["power"] = power .. ":" .. maxPower .. ":" .. powerName
  
  local race
  race = UnitRace(unitID)
  mob["race"] = race
  
  local gender
  gender = UnitSex(unitID)
  mob["gender"] = gender
  
  TallyMobTable[guidToStoreUnder] = mob
end -- function storeData(string)

-- LOOT_OPENED event handler
--
-- Handles the event that occurs when the loot window opens
--
function events:LOOT_OPENED(...)
  local numItems = GetNumLootItems();
  
  for numItem = 1, numItems do
    local lootSources = {GetLootSourceInfo(numItem)};

    local index = 1;
    
    repeat
      local flag = false;

      local lootSource = lootSources[index];
      index = index + 1;

      local lootAmount = lootSources[index];
      index = index + 1;

      if lootSource == nil then
        flag = true;
      else
        local mobID = ParseGUID(lootSource);
      end
    until flag == true;
  end
end -- LOOT_OPENED event handler

-- Function loadHandler
--
-- Loads the various event handlers in
--
function loadHandler(self)
  print ("Registering events");
  for k, v in pairs(events) do
    self:RegisterEvent(k)
  end
end -- Function loadHandler

-- Function EventHandler_OnEvent
--
-- Calls the relevant event with the appropriate parameters
--
function EventHandler_OnEvent(self, event, ...)
  events[event](self, ...);
end -- Function EventHandler_OnEvent

function ParseGUID(guid)
   local first3 = tonumber("0x"..strsub(guid, 3,5))
   local unitType = bit.band(first3,0x00f)
   
   local returnValue

   if (unitType == 0x000) then  -- we have a player
      return strsub(guid, 6), "PLAYER";
   elseif (unitType == 0x003) then -- we have a NPC
      return tonumber("0x"..strsub(guid,7,10)), "NPC";
   elseif (unitType == 0x004) then -- we have a permanent pet
      return tonumber("0x"..strsub(guid,7,10)), "PET";
   elseif (unitType == 0x005) then  -- we have a vehicle
      return tonumber("0x"..strsub(guid,7,10)), "VEHICLE";
   end
   
   return returnValue
end